@@ -43,8 +43,13 @@ static int   init_devtab (void);
    many-to-one: -1 on failed match.
 */
 dev_t name_to_dev(char* name) {
-    static struct stat sbuf;
-    return (stat(name_to_path(name), &sbuf) < 0) ? -1 : sbuf.st_rdev;
+    struct stat sbuf;
+    if (*name) { /* use named tty */
+	if (stat(name_to_path(name), &sbuf) < 0) return -1;
+    }
+    else if (fstat(0, &sbuf) < 0) return -1; /* use current tty */
+    if (!S_ISCHR(sbuf.st_mode)) return -1;
+    return sbuf.st_rdev;
 }
 
 /* find m in a[] assuming a is sorted into ascending order */
