@@ -244,7 +244,7 @@ int main(int argc, char **argv) {
 	    fprintf(stderr, "the name `%s' is not a tty\n", CL_ctty);
 	    exit(1);
 	}
-	pflags = (pflags | PROC_TTY) & ~PROC_ANYTTY;
+	pflags = (pflags | PROC_TTY) & ~(PROC_ANYTTY|PROC_STAT|PROC_UID|PROC_PID);
 	args = tty;
     }
     show_procs(cmdspc, do_header, pflags, args, N);
